@@ -1,6 +1,7 @@
 import logging
 from typing import List, Optional
 
+from allauth import app_settings as allauth_settings
 from allauth.account import app_settings
 from allauth.account.adapter import get_adapter
 from allauth.account.app_settings import EmailVerificationMethod
@@ -8,7 +9,7 @@ from allauth.account.internal.constants import LoginStageKey
 from allauth.account.internal.flows.email_verification import (
     send_verification_email_at_login,
 )
-from allauth.account.models import EmailAddress
+from allauth.account.models import EmailAddress, Login
 from allauth.core.internal.httpkit import headed_redirect_response
 from allauth.utils import import_callable
 
@@ -19,6 +20,7 @@ logger = logging.getLogger(__name__)
 class LoginStage:
     key: str  # Set in subclasses
     urlname: Optional[str] = None
+    login: Login
 
     def __init__(self, controller, request, login):
         if not self.key:
@@ -174,8 +176,12 @@ class LoginByCodeStage(LoginStage):
         if not did_initiate_process and not login_by_code_required:
             # Didn't initiate login by code process, but not required, so continue.
             return None, True
+        elif self._is_trusted():
+            return None, True
         elif not did_initiate_process and login_by_code_required:
-            email = EmailAddress.objects.get_primary_email(self.login.user)
+            email = self.login.email or EmailAddress.objects.get_primary_email(
+                self.login.user
+            )
             phone = None
             phone_field = app_settings.SIGNUP_FIELDS.get("phone")
             if not email and phone_field:
@@ -193,10 +199,22 @@ class LoginByCodeStage(LoginStage):
                 email=email,
                 stage=self,
             )
-
+        self.state["login_by_code_required"] = True
         response = headed_redirect_response("account_confirm_login_code")
         return response, True
 
+    def _is_trusted(self) -> bool:
+        if (
+            not app_settings.LOGIN_BY_CODE_TRUST_ENABLED
+            or not allauth_settings.MFA_ENABLED
+            or self.login.user is None
+        ):
+            return False
+
+        from allauth.mfa.internal.flows import trust
+
+        return trust.is_trusted_browser(self.request, self.login.user)
+
 
 class PhoneVerificationStage(LoginStage):
     key = LoginStageKey.VERIFY_PHONE.value
