@@ -40,6 +40,11 @@ urlpatterns = [
                                 views.device_authorization,
                                 name="device_authorization",
                             ),
+                            path(
+                                "logout",
+                                views.logout,
+                                name="logout",
+                            ),
                             path(
                                 "api/",
                                 include(
