@@ -1,8 +1,7 @@
+from allauth.socialaccount.providers.atlassian.views import AtlassianOAuth2Adapter
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
 
-from .views import AtlassianOAuth2Adapter
-
 
 class AtlassianAccount(ProviderAccount):
     def get_profile_url(self):
