@@ -4,10 +4,7 @@ from collections import OrderedDict
 from django.utils.http import urlencode
 
 from allauth.socialaccount.adapter import get_adapter
-from allauth.socialaccount.providers.oauth2.client import (
-    OAuth2Client,
-    OAuth2Error,
-)
+from allauth.socialaccount.providers.oauth2.client import OAuth2Client, OAuth2Error
 
 
 class FeishuOAuth2Client(OAuth2Client):
