@@ -12,14 +12,14 @@ Resources:
 * Steam Partner API documentation
     https://partner.steamgames.com/doc/features/auth#website
 """
+
 from django.urls import reverse
 
 from allauth.socialaccount.providers.openid.views import (
     OpenIDCallbackView,
     OpenIDLoginView,
 )
-
-from .provider import SteamOpenIDProvider
+from allauth.socialaccount.providers.steam.provider import SteamOpenIDProvider
 
 
 STEAM_OPENID_URL = "https://steamcommunity.com/openid"
