@@ -1,11 +1,10 @@
 """
 Provider for Patreon
 """
+
 from allauth.socialaccount.providers.base import ProviderAccount
 from allauth.socialaccount.providers.oauth2.provider import OAuth2Provider
-from allauth.socialaccount.providers.vimeo_oauth2.views import (
-    VimeoOAuth2Adapter,
-)
+from allauth.socialaccount.providers.vimeo_oauth2.views import VimeoOAuth2Adapter
 
 
 class VimeoOAuth2Account(ProviderAccount):
