@@ -1,6 +1,5 @@
 from allauth.socialaccount.providers.oauth2.urls import default_urlpatterns
-
-from .provider import WahooProvider
+from allauth.socialaccount.providers.wahoo.provider import WahooProvider
 
 
 urlpatterns = default_urlpatterns(WahooProvider)
